"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BootstrapLog = void 0;
const common_1 = require("@nestjs/common");
const colors = require("colors");
function BootstrapLog(options) {
    const { config } = options;
    const { redis_url, database_url, environment, hostname, package_json_body, health_check, swagger, sentry } = config;
    const logger = new common_1.Logger('Bootstrap');
    logger.log(colors.green.bold(`🎉 Bootstrapping ${package_json_body.name}:${package_json_body.version}`));
    logger.log(colors.red.bold(`🚀 Server is using ${environment} environment`));
    logger.log(colors.blue.bold(`✅ Server running on 👉 ${hostname}`));
    if (database_url) {
        logger.log(colors.blue.bold(`💾 Database ${database_url}`));
    }
    if (swagger) {
        logger.log(colors.green.bold(`📄 Swagger 👉 ${hostname}/swagger/`));
    }
    if (health_check) {
        logger.log(colors.green.bold(`🩺 Check Health 👉 ${hostname}/health`));
    }
    if (redis_url) {
        logger.log(colors.magenta.bold(`📮 Connected to ${redis_url}`));
    }
    if (sentry) {
        logger.log(colors.blue.bold(`📶 Setting up Sentry for ${environment} environment`));
    }
}
exports.BootstrapLog = BootstrapLog;
//# sourceMappingURL=bootstrap-log.js.map